# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 08:02:21 2018 from module list in Acme::CPANLists::Import::PerlDancerAdvent::2014 version 0.002.

package Acme::CPANModules::Import::PerlDancerAdvent::2014;

our $DATE = '2018-09-22'; # DATE
our $VERSION = '0.001'; # VERSION

our $LIST = {
  description => "This list is generated by extracting module names mentioned in [http://advent.perldancer.org/2014/] (retrieved on 2016-11-18). Visit the URL for the full contents.",
  entries     => [
                   { module => "DBIx::Class" },
                   { module => "Dancer" },
                   { module => "Dancer2" },
                   { module => "Amon2" },
                   { module => "App::Cmd" },
                   { module => "HTTP::Server::PSGI" },
                   { module => "Moo" },
                   { module => "Moose" },
                   { module => "Plack" },
                   { module => "Carton" },
                   { module => "HTTP::Server::Simple" },
                   { module => "Pinto" },
                   { module => "Plack::Builder" },
                   { module => "local::lib" },
                   { module => "App::FatPacker" },
                   { module => "MIME::Types" },
                   { module => "PSGI" },
                   { module => "Dancer2::Handler::AutoPage" },
                   { module => "Dancer2::Handler::File" },
                   { module => "Plack::Middleware::Static" },
                   { module => "File::Spec" },
                   { module => "HTTP::Tiny" },
                   { module => "JSON" },
                   { module => "Template" },
                   { module => "Dancer2::Core::App" },
                   { module => "Dancer2::Core::Dispatcher" },
                   { module => "Plack::App::URLMap" },
                   { module => "Dancer2::Serializer::CBOR" },
                   { module => "Dancer2::Test" },
                   { module => "Dancer::Test" },
                   { module => "HTTP::Cookies" },
                   { module => "HTTP::Request" },
                   { module => "HTTP::Response" },
                   { module => "LWP" },
                   { module => "LWP::Protocol::PSGI" },
                   { module => "LWP::UserAgent" },
                   { module => "Plack::Test" },
                   { module => "Test::More" },
                   { module => "Test::WWW::Mechanize" },
                   { module => "Test::WWW::Mechanize::PSGI" },
                   { module => "WWW::Mechanize" },
                   { module => "Dancer2::Core::Factory" },
                   { module => "Dancer2::Plugin" },
                   { module => "Dancer2::Plugin::Auth::Tiny" },
                   { module => "Dancer2::Plugin::Database" },
                   { module => "Dancer2::Plugin::Auth::Extensible" },
                   { module => "Dancer2::Plugin::Passphrase" },
                   { module => "Digest" },
                   { module => "Plack::Middleware" },
                   { module => "Plack::Middleware::ContentLength" },
                   { module => "Plack::Middleware::FixMissingBodyInRedirect" },
                   { module => "Plack::Middleware::Head" },
                   { module => "Plack::Middleware::RemoveRedundantBody" },
                   { module => "Plack::Util" },
                 ],
  summary     => "Modules mentioned in PerlDancer Advent Calendar 2014",
};

1;
# ABSTRACT: Modules mentioned in PerlDancer Advent Calendar 2014

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::Import::PerlDancerAdvent::2014 - Modules mentioned in PerlDancer Advent Calendar 2014

=head1 VERSION

This document describes version 0.001 of Acme::CPANModules::Import::PerlDancerAdvent::2014 (from Perl distribution Acme-CPANModulesBundle-Import-PerlDancerAdvent-2014), released on 2018-09-22.

=head1 DESCRIPTION

Modules mentioned in PerlDancer Advent Calendar 2014.

This list is generated by extracting module names mentioned in [http://advent.perldancer.org/2014/] (retrieved on 2016-11-18). Visit the URL for the full contents.

=head1 INCLUDED MODULES

=over

=item * L<DBIx::Class>

=item * L<Dancer>

=item * L<Dancer2>

=item * L<Amon2>

=item * L<App::Cmd>

=item * L<HTTP::Server::PSGI>

=item * L<Moo>

=item * L<Moose>

=item * L<Plack>

=item * L<Carton>

=item * L<HTTP::Server::Simple>

=item * L<Pinto>

=item * L<Plack::Builder>

=item * L<local::lib>

=item * L<App::FatPacker>

=item * L<MIME::Types>

=item * L<PSGI>

=item * L<Dancer2::Handler::AutoPage>

=item * L<Dancer2::Handler::File>

=item * L<Plack::Middleware::Static>

=item * L<File::Spec>

=item * L<HTTP::Tiny>

=item * L<JSON>

=item * L<Template>

=item * L<Dancer2::Core::App>

=item * L<Dancer2::Core::Dispatcher>

=item * L<Plack::App::URLMap>

=item * L<Dancer2::Serializer::CBOR>

=item * L<Dancer2::Test>

=item * L<Dancer::Test>

=item * L<HTTP::Cookies>

=item * L<HTTP::Request>

=item * L<HTTP::Response>

=item * L<LWP>

=item * L<LWP::Protocol::PSGI>

=item * L<LWP::UserAgent>

=item * L<Plack::Test>

=item * L<Test::More>

=item * L<Test::WWW::Mechanize>

=item * L<Test::WWW::Mechanize::PSGI>

=item * L<WWW::Mechanize>

=item * L<Dancer2::Core::Factory>

=item * L<Dancer2::Plugin>

=item * L<Dancer2::Plugin::Auth::Tiny>

=item * L<Dancer2::Plugin::Database>

=item * L<Dancer2::Plugin::Auth::Extensible>

=item * L<Dancer2::Plugin::Passphrase>

=item * L<Digest>

=item * L<Plack::Middleware>

=item * L<Plack::Middleware::ContentLength>

=item * L<Plack::Middleware::FixMissingBodyInRedirect>

=item * L<Plack::Middleware::Head>

=item * L<Plack::Middleware::RemoveRedundantBody>

=item * L<Plack::Util>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-Import-PerlDancerAdvent-2014>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-Import-PerlDancerAdvent-2014>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-Import-PerlDancerAdvent-2014>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
